@@ -15,9 +15,11 @@ from typing import NamedTuple
 # ##################################
 class PageInformation(NamedTuple):
     abs_path: Path = None
+    authors: tuple = None
     created: datetime = None
     updated: datetime = None
     title: str = None
     description: str = None
     image: str = None
     url_full: str = None
+    src_path: str = None
