@@ -6,6 +6,7 @@
 
 # standard library
 import logging
+import re
 import ssl
 from datetime import date, datetime
 from email.utils import formatdate
@@ -17,6 +18,7 @@ from urllib.error import HTTPError
 from urllib.parse import urlencode, urlparse, urlunparse
 
 # 3rd party
+import markdown
 from git import GitCommandError, GitCommandNotFound, InvalidGitRepositoryError, Repo
 from mkdocs.config.config_options import Config
 from mkdocs.structure.pages import Page
@@ -188,6 +190,44 @@ class Util:
                 get_build_timestamp(),
             )
 
+    def get_authors_from_meta(self, in_page: Page) -> Tuple[str] or None:
+        """Returns authors from page meta. It handles 'author' and 'authors' for keys, \
+        str and iterable as values types.
+
+        Args:
+            in_page (Page): page to look at
+
+        Returns:
+            Tuple[str]: tuple of authors names
+        """
+        # identify the key
+        if "author" in in_page.meta:
+            if isinstance(in_page.meta.get("author"), str):
+                return (in_page.meta.get("author"),)
+            elif isinstance(in_page.meta.get("author"), (list, tuple)):
+                return tuple(in_page.meta.get("author"))
+            else:
+                logging.warning(
+                    "[rss-plugin] Type of author value in page.meta (%s) is not valid. "
+                    "It should be str, list or tuple, not: %s."
+                    % in_page.file.abs_src_path,
+                    type(in_page.meta.get("author")),
+                )
+                return None
+        elif "authors" in in_page.meta:
+            if isinstance(in_page.meta.get("authors"), str):
+                return (in_page.meta.get("authors"),)
+            elif isinstance(in_page.meta.get("authors"), (list, tuple)):
+                return tuple(in_page.meta.get("authors"))
+            else:
+                logging.warning(
+                    "[rss-plugin] Type of authors value in page.meta (%s) is not valid. "
+                    "It should be str, list or tuple, not: %s."
+                    % in_page.file.abs_src_path,
+                    type(in_page.meta.get("authors")),
+                )
+                return None
+
     def get_date_from_meta(
         self, date_metatag_value: str, meta_datetime_format: str
     ) -> float:
@@ -223,8 +263,9 @@ class Util:
         """Returns description from page meta. If it doesn't exist, use the \
         {chars_count} first characters from page content (in markdown).
 
-        :param Page in_page: [description]
-        :param int chars_count: [description]. Defaults to: 150 - optional
+        :param Page in_page: page to look at
+        :param int chars_count: if page.meta.description is not set, number of chars \
+        of the content to use. Defaults to: 150 - optional
 
         :return: page description to use
         :rtype: str
@@ -232,9 +273,25 @@ class Util:
         if in_page.meta.get("description"):
             return in_page.meta.get("description")
         elif in_page.content:
-            return in_page.content[:chars_count]
+            if len(in_page.content) < chars_count:
+                return markdown.markdown(
+                    in_page.content[:chars_count], output_format="html5"
+                )
+            else:
+                return markdown.markdown(
+                    "{}...".format(in_page.content[: chars_count - 3]),
+                    output_format="html5",
+                )
         elif in_page.markdown:
-            return in_page.markdown[:chars_count]
+            if len(in_page.markdown) < chars_count:
+                return markdown.markdown(
+                    in_page.markdown[:chars_count], output_format="html5"
+                )
+            else:
+                return markdown.markdown(
+                    "{}...".format(in_page.markdown[: chars_count - 3]),
+                    output_format="html5",
+                )
         else:
             return ""
 
@@ -401,11 +458,11 @@ class Util:
             return None
 
     @staticmethod
-    def filter_pages(pages: dict, attribute: str, length: int) -> list:
+    def filter_pages(pages: list, attribute: str, length: int, match_path: str) -> list:
         """Filter and return pages into a friendly RSS structure.
 
         :param pages: pages to filter
-        :type pages: dict
+        :type pages: list
         :param attribute: page attribute as filter variable
         :type attribute: str
         :param length: max number of pages to return
@@ -415,11 +472,15 @@ class Util:
         :rtype: list
         """
         filtered_pages = []
+        path_pattern = re.compile(match_path) if match_path else None
         for page in sorted(
             pages, key=lambda page: getattr(page, attribute), reverse=True
         )[:length]:
+            if path_pattern and not path_pattern.match(page.src_path):
+                continue
             filtered_pages.append(
                 {
+                    "authors": page.authors,
                     "description": page.description,
                     "link": page.url_full,
                     "pubDate": formatdate(getattr(page, attribute)),
